**************************************
* This program creates Figure 1
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Figure 1. Baseline
* Europe, Spring 2010 Forecasts
*****************************************

* Set up sample
cap drop sample
gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

* Fiscal adjustment forecast vs. growth forecast error
preserve
* Data adjustment
* Variables
sort ifscode year
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample:
keep if year==2011
keep if sample==1
* Regression
reg y x, r
local coef = _b[x]
local tstat = _b[x]/_se[x]
local coef = round(`coef',.01)
local tstat = round(`tstat',.01)
* Scatter:
local ytitle = "growth forecast error"
local xtitle = "forecast of fiscal consolidation"
local graphindex = 1
local title=""
drop if x==.|y==.
twoway ///
(lfit y x, ///
lwidth(thin) legend(off) title("`title'") ytitle("`ytitle'") xtitle("`xtitle'")) ///
(scatter y x, mlabel(wdicode) mcolor(navy) msymbol(O) mlabsize(med) mlabcolor(navy) ///
saving(`graphindex', replace))
sort wdicode
clist wdicode y x, noobs
restore

log close
