**************************************
* This program creates Figure 2
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Figure 2. 
* Scatter: 2009-2012 Panel
*****************************************

* Set up sample
cap drop sample
gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

* Panel: scatter chart
preserve
* Variables
sort ifscode year
bys ifscode: gen y = .
bys ifscode: gen x = .
* Vintages loop
set more off
forval year = 1998/2013 {
	local year_m1 = `year'-1
	bys ifscode: replace y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch`year_m1'spring/100)*(1+ngdp_rpch`year_m1'spring[_n-1]/100)-1) if year==`year'
	bys ifscode: replace x = ggsb_gdp`year_m1'spring-ggsb_gdp`year_m1'spring[_n-2] if year==`year'
}
* Sample:
keep if sample==1
* Regression
* Chart
twoway ///
(lfit y x if year>=2010 & year<=2013, lwidth(thin)) ///
(scatter y x if year==2010, mcolor(navy) msymbol(O)) ///
(scatter y x if year==2011, mcolor(ebblue) msymbol(D)) ///
(scatter y x if year==2012, mcolor(eltblue) msymbol(T)) ///
(scatter y x if year==2013, mcolor(erose) msymbol(S) ///
ytitle("growth forecast error") xtitle("fiscal consolidation forecast") ///
legend(label(2 "2009") label(3 "2010") label(4 "2011") label(5 "2012") row(1) ///
order(2 3 4 5)) )
restore

log close



