**************************************
* This program creates Table 6
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Table 6. Europe: Unemployment 
* and GDP Components
*****************************************

preserve
* Settings
local title = "Real GDP"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "Private consumption"
* Variables
bys ifscode: gen y = 100*((1+ncp_rpch2012fall/100)*(1+ncp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ncp_rpch2010spring/100)*(1+ncp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Investment"
* Variables
bys ifscode: gen y = 100*((nfi_r2012fall/nfi_r2012fall[_n-2]) - 1)  -  100*((nfi_r2010spring/nfi_r2010spring[_n-2]) - 1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Exports"
* Variables
bys ifscode: gen y = 100*((1+nx_rpch2012fall/100)*(1+nx_rpch2012fall[_n-1]/100)-1)  -  100*((1+nx_rpch2010spring/100)*(1+nx_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Imports"
* Variables
bys ifscode: gen y = 100*((1+nm_rpch2012fall/100)*(1+nm_rpch2012fall[_n-1]/100)-1)  -  100*((1+nm_rpch2010spring/100)*(1+nm_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Unemployment rate"
* Variables
bys ifscode: gen y = (lur2012fall-lur2012fall[_n-2])  -  (lur2010spring-lur2010spring[_n-2])
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "GDP Deflator"
* Variables
bys ifscode: gen y = 100*((ngdp_d2012fall/ngdp_d2012fall[_n-2])-1)  -  100*((ngdp_d2010spring/ngdp_d2010spring[_n-2])-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T6.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore


log close

